@@ -129,8 +129,7 @@ class App(object):
             get(self.project_paths[instance] + dump_file, dump_file)
             self.run('rm ' + dump_file)
 
-            self.local_management_command('syncdb --migrate')
-            self.local_management_command('flush --noinput')
+            self.local_management_command('syncdb --migrate --noinput')
             self.local_management_command('loaddata ' + dump_file)
 
         # ... then cleanup the dump file
